@@ -153,7 +153,7 @@ func (s *Site) logMissingLayout(name, layout, kind, outputFormat string) {
 	}
 
 	errMsg := "You should create a template file which matches Hugo Layouts Lookup Rules for this combination."
-	var args []interface{}
+	var args []any
 	msg := "found no layout file for"
 	if outputFormat != "" {
 		msg += " %q"
