@@ -24,6 +24,11 @@ import (
 	"github.com/gohugoio/hugo/common/hugio"
 )
 
+var (
+	_ ResourceDataProvider = (*resourceError)(nil)
+	_ ResourceError        = (*resourceError)(nil)
+)
+
 // Cloner is an internal template and not meant for use in the templates. It
 // may change without notice.
 type Cloner interface {
@@ -37,9 +42,33 @@ type OriginProvider interface {
 	GetFieldString(pattern string) (string, bool)
 }
 
+// NewResourceError creates a new ResourceError.
+func NewResourceError(err error, data any) ResourceError {
+	return &resourceError{
+		error: err,
+		data:  data,
+	}
+}
+
+type resourceError struct {
+	error
+	data any
+}
+
+// The data associated with this error.
+func (e *resourceError) Data() any {
+	return e.data
+}
+
+// ResourceError is the error return from .Err in Resource in error situations.
+type ResourceError interface {
+	error
+	ResourceDataProvider
+}
+
 // ErrProvider provides an Err.
 type ErrProvider interface {
-	Err() error
+	Err() ResourceError
 }
 
 // Resource represents a linkable resource, i.e. a content page, image etc.
@@ -66,7 +95,7 @@ type ImageOps interface {
 	Fill(spec string) (Image, error)
 	Fit(spec string) (Image, error)
 	Resize(spec string) (Image, error)
-	Filter(filters ...interface{}) (Image, error)
+	Filter(filters ...any) (Image, error)
 	Exif() *exif.Exif
 
 	// Internal
@@ -119,7 +148,7 @@ type ResourceParamsProvider interface {
 type ResourceDataProvider interface {
 	// Resource specific data set by Hugo.
 	// One example would be.Data.Digest for fingerprinted resources.
-	Data() interface{}
+	Data() any
 }
 
 // ResourcesLanguageMerger describes an interface for merging resources from a
@@ -127,7 +156,7 @@ type ResourceDataProvider interface {
 type ResourcesLanguageMerger interface {
 	MergeByLanguage(other Resources) Resources
 	// Needed for integration with the tpl package.
-	MergeByLanguageInterface(other interface{}) (interface{}, error)
+	MergeByLanguageInterface(other any) (any, error)
 }
 
 // Identifier identifies a resource.
@@ -152,7 +181,7 @@ type ContentProvider interface {
 	// * Page: template.HTML
 	// * JSON: String
 	// * Etc.
-	Content() (interface{}, error)
+	Content() (any, error)
 }
 
 // OpenReadSeekCloser allows setting some other way (than reading from a filesystem)
