@@ -70,11 +70,12 @@ type FileWithoutOverlap interface {
 	// The directory is relative to the content root.
 	Dir() string
 
-	// Extension gets the file extension, i.e "myblogpost.md" will return "md".
+	// Extension is an alias to Ext().
+	// Deprecated: Use Ext instead.
 	Extension() string
 
-	// Ext is an alias for Extension.
-	Ext() string // Hmm... Deprecate Extension
+	// Ext gets the file extension, i.e "myblogpost.md" will return "md".
+	Ext() string
 
 	// LogicalName is filename and extension of the file.
 	LogicalName() string
@@ -139,7 +140,10 @@ func (fi *FileInfo) Path() string { return fi.relPath }
 func (fi *FileInfo) Dir() string { return fi.relDir }
 
 // Extension is an alias to Ext().
-func (fi *FileInfo) Extension() string { return fi.Ext() }
+func (fi *FileInfo) Extension() string {
+	helpers.Deprecated(".File.Extension", "Use .File.Ext instead. ", false)
+	return fi.Ext()
+}
 
 // Ext returns a file's extension without the leading period (ie. "md").
 func (fi *FileInfo) Ext() string { return fi.ext }
